Index: main/manager.c
===================================================================
--- main/manager.c	(revision 212169)
+++ main/manager.c	(working copy)
@@ -1718,10 +1718,33 @@
 		return 0;
 	}
 	if (chan->pbx) {
-		ast_channel_lock(chan);
-		ast_set_flag(chan, AST_FLAG_BRIDGE_HANGUP_DONT); /* don't let the after-bridge code run the h-exten */
-		ast_channel_unlock(chan);
+		struct ast_cdr *cdr;
+
+		/* Create a new cdr record. The reasoning here is as follows:
+		 * because the channel with the PBX on it generally stores the
+		 * CDR record, we fork the CDR so that the information from the
+		 * original call is not lost.
+		 */
+		if (!(cdr = ast_cdr_dup(chan->cdr))) {
+			astman_send_error(s, m, "Redirect failed, error allocating CDR.");
+			ast_channel_unlock(chan);
+			if (chan2) {
+				ast_channel_unlock(chan2);
+			}
+			return 0;
+		}
+
+		ast_cdr_reset(cdr, NULL);
+		ast_cdr_init(cdr, chan);
+
+		ast_cdr_end(chan->cdr);
+		ast_set_flag(chan->cdr, AST_CDR_FLAG_DONT_TOUCH | AST_CDR_FLAG_LOCKED);
+		ast_cdr_append(chan->cdr, cdr);
+
+		/* don't let the after-bridge code run the h-exten */
+		ast_set_flag(chan, AST_FLAG_BRIDGE_HANGUP_DONT);
 	}
+
 	res = ast_async_goto(chan, context, exten, pi);
 	if (!res) {
 		if (!ast_strlen_zero(name2)) {
